@@ -1,7 +1,8 @@
 
-from wxPython import wx
 
+import wx
 from XRCWidgets import XRCApp, XRCDialog
+
 from demo_widgets import DemoPanel
 
 #  Simple frame to demonstrate the use of menus and toolbar.
@@ -18,7 +19,7 @@ class DemoApp(XRCApp):
         p = DemoPanel(dsp)
         self.replaceInWindow(dsp,p)
 
-    def on_tb_new_activate(self):
+    def on_tb_new_activate(self,evt):
         self.on_m_file_new_activate(None)
 
     def on_m_help_about_activate(self,evt):
@@ -27,7 +28,7 @@ class DemoApp(XRCApp):
         dlg.ShowModal()
         dlg.Destroy()
 
-    def on_tb_about_activate(self):
+    def on_tb_about_activate(self,evt):
         self.on_m_help_about_activate(None)
 
     def on_displayarea_content(self,ctrl):
